pub struct AgentStats {
pub completed_block_tasks: u64,
pub completed_cron_tasks: u64,
pub missed_blocked_tasks: u64,
pub missed_cron_tasks: u64,
pub last_executed_slot: u64,
}Fields
completed_block_tasks: u64completed_cron_tasks: u64missed_blocked_tasks: u64missed_cron_tasks: u64last_executed_slot: u64Trait Implementations
Sourceimpl Clone for AgentStats
impl Clone for AgentStats
Sourcefn clone(&self) -> AgentStats
fn clone(&self) -> AgentStats
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentStats
impl Debug for AgentStats
Sourceimpl Default for AgentStats
impl Default for AgentStats
Sourcefn default() -> AgentStats
fn default() -> AgentStats
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AgentStats
impl<'de> Deserialize<'de> for AgentStats
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AgentStats, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AgentStats, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentStats
impl JsonSchema for AgentStats
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AgentStats
impl PartialEq for AgentStats
Sourceimpl Serialize for AgentStats
impl Serialize for AgentStats
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AgentStats